@@ -1,4 +1,4 @@
-VERSION = (1, 5, 2)
+VERSION = (1, 5, 3)
 __version__ = '.'.join(map(str, VERSION))
 
 
@@ -8,7 +8,7 @@ class LazySettings(object):
         from django.conf import settings as django_settings
 
         for key in dir(default_settings):
-            if not (key.startswith('FEINCMS_') or key.startswith('_HACK_')):
+            if not key.startswith('FEINCMS_'):
                 continue
 
             setattr(self, key, getattr(django_settings, key,
